@@ -1,8 +1,8 @@
 import random
 from contextlib import contextmanager
-from typing import Callable, Iterator, List, Tuple
+from typing import Callable, Dict, Iterator, List, Tuple
 
-__version__ = "0.0.4"
+__version__ = "0.0.5"
 
 
 def encode(text: str) -> str:
@@ -92,6 +92,10 @@ def _scramble_word(word: str, reverse=False) -> str:
     return f"{word[0]}{scrambled_substring}{word[-1]}"
 
 
+class _Cache:
+    sequences: Dict[Tuple[int, int], List[int]] = {}
+
+
 def _get_scrambling_sequence(word: str) -> List[int]:
     """ Get a pseudo random, reproducible scrambling sequence.
 
@@ -110,6 +114,9 @@ def _get_scrambling_sequence(word: str) -> List[int]:
     assert length > 0, "That shouldn't happen. Developer screwed up."
     seed = ord(word[0]) + length + ord(word[-1])
 
+    if (length, seed) in _Cache.sequences:
+        return _Cache.sequences[(length, seed)]
+
     random.seed(seed, version=2)
     ordered = range(length - 2)
     sequence = random.sample(ordered, length - 2)
@@ -120,6 +127,7 @@ def _get_scrambling_sequence(word: str) -> List[int]:
         # for this case, let's reverse the sequence to enforce encoding.
         sequence.reverse()
 
+    _Cache.sequences[(length, seed)] = sequence
     return sequence
 
 
